StackedCards class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- StackedCards
Constructors
-
StackedCards({Key? key, required List<
Widget> items, required double itemHeight, required double itemWidth, required double totalHeight, required double totalWidth, required double spaceIntervalFactor, required int stackLevels, required bool autoRotate, required Axis scrollDirection, void onCardChange(int)?, void onDragUpdate(double progress, double direction)?, VoidCallback? onDragEnd}) -
const
Properties
- autoRotate → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemHeight → double
-
final
-
items
→ List<
Widget> -
final
- itemWidth → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCardChange → void Function(int)?
-
final
- onDragEnd → VoidCallback?
-
final
- onDragUpdate → void Function(double progress, double direction)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollDirection → Axis
-
final
- spaceIntervalFactor → double
-
final
- stackLevels → int
-
final
- totalHeight → double
-
final
- totalWidth → double
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StackedCards> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited